[asterisk-scf-commits] asterisk-scf/release/cmake.git branch "master" updated.

Commits to the Asterisk SCF project code repositories asterisk-scf-commits at lists.digium.com
Thu Oct 14 18:22:46 CDT 2010


branch "master" has been updated
       via  cd39ae824f03a19dc934709caee21e930f3b9988 (commit)
      from  17066de364794f3befcdcca030ca31d349e83eea (commit)

Summary of changes:
 AsteriskSCF.cmake      |  130 ++++++++++++++++++++++++------------------------
 example/CMakeLists.txt |   48 +++++++++---------
 2 files changed, 89 insertions(+), 89 deletions(-)


- Log -----------------------------------------------------------------
commit cd39ae824f03a19dc934709caee21e930f3b9988
Author: Ken Hunt <ken.hunt at digium.com>
Date:   Thu Oct 14 18:23:25 2010 -0500

    Replacing references to project's old internal working name.

diff --git a/example/CMakeLists.txt b/example/CMakeLists.txt
index 9a490ba..61943e5 100644
--- a/example/CMakeLists.txt
+++ b/example/CMakeLists.txt
@@ -27,7 +27,7 @@ include(../AsteriskSCF_v4.cmake)
 # as arguments as well. Finally, the major/minor version of ICE used by the project must be included for
 # proper dependency checking.
 #
-hydra_project(example 3.4 CXX)
+asterisk_scf_project(example 3.4 CXX)
 
 # The next function calls setup components to be built. The first one (examplebox) is built as an Icebox
 # service while the second (example) is built as a standalone executable.
@@ -40,7 +40,7 @@ hydra_project(example 3.4 CXX)
 # track of component Slice definitions, sources, and other things for a component. It *must* be
 # called before executing any other Asterisk SCF component function. This function also does dependency
 # checking unique to the language specified.
-hydra_component_init(examplebox CXX)
+asterisk_scf_component_init(examplebox CXX)
 
 # If you have additional third party dependencies for your component the CMake logic to find them can be
 # inserted here.
@@ -53,21 +53,21 @@ hydra_component_init(examplebox CXX)
 # those definitions can be specified with this function; note that just like CMake's standard include_directories()
 # function, this applies to the entire directory it is included in, not just a single target, and all
 # its subdirectories
-hydra_slice_include_directories(/home/zaphod/slice)
+asterisk_scf_slice_include_directories(/home/zaphod/slice)
 
 # If a Slice definition requires macro definitions, they can be specified with this function.
-hydra_slice_compile_definitions(fluxcapacitor SERVER JOSH=LEET2)
+asterisk_scf_slice_compile_definitions(fluxcapacitor SERVER JOSH=LEET2)
 
 # If a Slice definition uses any Ice-provided definitions (for example, IceBox or IceStorm), then for
 # some languages it is necessary to reference the Ice-provided libraries containing those definitions
 # when building the target. The names of the needed libraries can be provided using this function.
-hydra_slice_add_ice_libraries(fluxcapacitor IceStorm)
+asterisk_scf_slice_add_ice_libraries(fluxcapacitor IceStorm)
 
 # This function compiles a Slice definition (or more than one) into one or more libraries, one for each
 # language used in the project. It produces a target named the same as the Slice file without the extension,
-# which can be used in calls to hydra_slice_include_directories(), hydra_slice_compile_definitions(),
-# hydra_component_add_slice(), and hydra_slice_add_ice_libraries().
-#  Parameters to hydra_compile_slice:
+# which can be used in calls to asterisk_scf_slice_include_directories(), asterisk_scf_slice_compile_definitions(),
+# asterisk_scf_component_add_slice(), and asterisk_scf_slice_add_ice_libraries().
+#  Parameters to asterisk_scf_compile_slice:
 #     - The target slice definition filename. 
 #     - The subdirectory in which to install the output of the build. "lib" is good for most cases, but some 
 #       optional components may choose to install elsewhere. 
@@ -75,54 +75,54 @@ hydra_slice_add_ice_libraries(fluxcapacitor IceStorm)
 #       in the installer. 
 #     - Group for use by the packager. The group should be previously configured in the CPackConfig.cmake file. The user
 #       is typically allowed to select specific groups during a custom install process. 
-hydra_compile_slice(fluxcapacitor.ice lib "Slice Defined API" Core)
+asterisk_scf_compile_slice(fluxcapacitor.ice lib "Slice Defined API" Core)
 
 # This function takes a component name and Slice target as parameters. It adds the Slice target
 # to the component so it is compiled in and so the headers are made available.
-hydra_component_add_slice(examplebox fluxcapacitor)
+asterisk_scf_component_add_slice(examplebox fluxcapacitor)
 
 # This function takes a component name and source file as parameters. The source file is added in so it gets
 # compiled into the component. This *must* be called from the same directory that the source file exists in.
-hydra_component_add_file(examplebox example.cpp)
+asterisk_scf_component_add_file(examplebox example.cpp)
 
 # If a component uses any Ice-provided definitions (for example, IceBox or IceStorm), then for
 # some languages it is necessary to reference the Ice-provided libraries containing those definitions
 # when building the component. The names of the needed libraries can be provided using this function.
 # It is not necessary to specify that IceBox is required for IceBox services, as the
-# hydra_component_build_icebox() function will handle that automatically.
-hydra_slice_add_ice_libraries(fluxcapacitor IceStorm)
+# asterisk_scf_component_build_icebox() function will handle that automatically.
+asterisk_scf_slice_add_ice_libraries(fluxcapacitor IceStorm)
 
 # This function takes a component name as the parameter. It builds an IceBox service that IceBox can load.
-hydra_component_build_icebox(examplebox)
+asterisk_scf_component_build_icebox(examplebox)
 
 # This function takes a component name as the parameter. It sets up an install target on the build environment
 # if possible.
-#  Parameters to hydra_compile_slice:
-#     - The component's name, as previously defined in a call to hydra_component_init().  
+#  Parameters to asterisk_scf_compile_slice:
+#     - The component's name, as previously defined in a call to asterisk_scf_component_init().  
 #     - The CMake install() command's type, as defined in CMake docs.
 #     - The subdirectory in which to install the output of the build. 
 #     - Description for use by the packager. This text typically appears when the user hovers over the component's name
 #       in the installer. 
 #     - Group name for use by the packager. The group should be previously configured in the CPackConfig.cmake file. The user
 #       is typically allowed to select specific groups during a custom install process. 
-hydra_component_install(examplebox LIBRARY lib "Icebox example component." Core)
+asterisk_scf_component_install(examplebox LIBRARY lib "Icebox example component." Core)
 
 # Now we move on to the next component, a standalone executable.
-hydra_component_init(example CXX)
-hydra_component_add_slice(example fluxcapacitor)
-hydra_component_add_file(example example.cpp)
+asterisk_scf_component_init(example CXX)
+asterisk_scf_component_add_slice(example fluxcapacitor)
+asterisk_scf_component_add_file(example example.cpp)
 
 # This function takes a component name as the parameter. It builds a standalone executable.
-hydra_component_build_standalone(example)
+asterisk_scf_component_build_standalone(example)
 
 # Specifies how to install the component. 
-#  Parameters to hydra_compile_slice:
-#     - The component's name, as previously defined in a call to hydra_component_init().  
+#  Parameters to asterisk_scf_compile_slice:
+#     - The component's name, as previously defined in a call to asterisk_scf_component_init().  
 #     - The CMake install() command's type, as defined in CMake docs.
 #     - The subdirectory in which to install the output of the build. 
 #     - Description for use by the packager. This text typically appears when the user hovers over the component's name
 #       in the installer. 
 #     - Group name for use by the packager. The group should be previously configured in the CPackConfig.cmake file. The user
 #       is typically allowed to select specific groups during a custom install process. 
-hydra_component_install(example RUNTIME bin "Example application." Core)
+asterisk_scf_component_install(example RUNTIME bin "Example application." Core)
 

-----------------------------------------------------------------------


diff --git a/AsteriskSCF.cmake b/AsteriskSCF.cmake
index 8725d52..a48041b 100644
--- a/AsteriskSCF.cmake
+++ b/AsteriskSCF.cmake
@@ -219,22 +219,22 @@ function(find_Boost_library LIBRARY)
 endfunction()
 
 # Function which initializes project specific things
-function(hydra_project NAME ICE_VERSION)
+function(asterisk_scf_project NAME ICE_VERSION)
   if(NOT ARGN)
     message(FATAL_ERROR "You must pass at least one language to this function")
   endif()
   message(STATUS "Setting up project ${NAME} for languages ${ARGN}")
-  set(HYDRA_PROJECT_LANGUAGES ${ARGN} PARENT_SCOPE)
-  set(HYDRA_ICE_VERSION ${ICE_VERSION} PARENT_SCOPE)
+  set(ASTERISK_SCF_PROJECT_LANGUAGES ${ARGN} PARENT_SCOPE)
+  set(ASTERISK_SCF_ICE_VERSION ${ICE_VERSION} PARENT_SCOPE)
   project(${NAME} ${ARGN})
   # On Windows, IceBox C++ services must be compiled with some symbols exported;
   # the source code should use HYDRA_ICEBOX_EXPORT to accomplish this, and this
   # block will ensure it contains the correct value.
   if(WIN32)
-    message(STATUS "Setting HYDRA_ICEBOX_EXPORT definition for Windows IceBox services")
-    add_definitions(-DHYDRA_ICEBOX_EXPORT=__declspec\(dllexport\))
+    message(STATUS "Setting ASTERISK_SCF_ICEBOX_EXPORT definition for Windows IceBox services")
+    add_definitions(-DASTERISK_SCF_ICEBOX_EXPORT=__declspec\(dllexport\))
   else()
-    add_definitions(-DHYDRA_ICEBOX_EXPORT=)
+    add_definitions(-DASTERISK_SCF_ICEBOX_EXPORT=)
   endif()
   # On Windows, 'debug' libraries should have a "d" suffix to indicate that they
   # are debug libraries
@@ -243,7 +243,7 @@ function(hydra_project NAME ICE_VERSION)
   endif()
   find_ICE(${ICE_VERSION})
   foreach(l ${ARGN})
-    set(HYDRA_ICE_LIBRARIES_${l} Ice PARENT_SCOPE)
+    set(ASTERISK_SCF_ICE_LIBRARIES_${l} Ice PARENT_SCOPE)
     # Perform requirement checking for each language to be used in the project
     if(l STREQUAL "Java")
       message(STATUS "Performing requirement checks for Java components")
@@ -269,7 +269,7 @@ function(hydra_project NAME ICE_VERSION)
       find_ICE_CXX_library(IceUtil)
       if(WIN32)
 	# On Windows, the IceUtil library must be explicitly linked
-	set(HYDRA_ICE_LIBRARIES_${l} Ice IceUtil PARENT_SCOPE)
+	set(ASTERISK_SCF_ICE_LIBRARIES_${l} Ice IceUtil PARENT_SCOPE)
       endif()
       message(STATUS "Include directories ${ICE_CXX_INCLUDE_DIR}")
       include_directories("${ICE_CXX_INCLUDE_DIR}")
@@ -282,12 +282,12 @@ endfunction()
 
 # Function which adds Ice libraries to all components in the current
 # directory and below
-function(hydra_add_ice_libraries)
+function(asterisk_scf_add_ice_libraries)
   if(NOT ARGN)
     message(FATAL_ERROR "You must pass at least one library to this function")
   endif()
-  foreach(lang ${HYDRA_PROJECT_LANGUAGES})
-    set(libs ${HYDRA_ICE_LIBRARIES_${lang}})
+  foreach(lang ${ASTERISK_SCF_PROJECT_LANGUAGES})
+    set(libs ${ASTERISK_SCF_ICE_LIBRARIES_${lang}})
     foreach(lib ${ARGN})
       if(lang STREQUAL "Java")
 	find_ICE_Java_library(${lib})
@@ -299,23 +299,23 @@ function(hydra_add_ice_libraries)
       list(APPEND libs ${lib})
     endforeach()
     list(REMOVE_DUPLICATES libs)
-    set(HYDRA_ICE_LIBRARIES_${lang} ${libs} PARENT_SCOPE)
+    set(ASTERISK_SCF_ICE_LIBRARIES_${lang} ${libs} PARENT_SCOPE)
   endforeach()
 endfunction()
 
 # Function which adds Boost libraries to all components in the current
 # directory and below
-function(hydra_add_boost_libraries)
+function(asterisk_scf_add_boost_libraries)
   if(NOT ARGN)
     message(FATAL_ERROR "You must pass at least one library to this function")
   endif()
-  set(libs ${HYDRA_BOOST_LIBRARIES})
+  set(libs ${ASTERISK_SCF_BOOST_LIBRARIES})
   foreach(lib ${ARGN})
     find_Boost_library(${lib})
     list(APPEND libs ${lib})
   endforeach()
   list(REMOVE_DUPLICATES libs)
-  set(HYDRA_BOOST_LIBRARIES ${libs} PARENT_SCOPE)
+  set(ASTERISK_SCF_BOOST_LIBRARIES ${libs} PARENT_SCOPE)
   include_directories(${Boost_INCLUDE_DIR})
   link_directories(${Boost_LIBRARY_DIRS})
 endfunction()
@@ -332,7 +332,7 @@ macro(ensure_abs_paths pathlist)
 endmacro()
 
 # Function which remembers include directories needed for a particular Slice target
-function(hydra_slice_include_directories)
+function(asterisk_scf_slice_include_directories)
   set(paths ${ARGN})
   ensure_abs_paths(paths)
   if(SLICE_INCLUDE_DIRECTORIES)
@@ -343,19 +343,19 @@ function(hydra_slice_include_directories)
 endfunction()
 
 # Function which remembers definitions needed for a particular Slice target
-function(hydra_slice_compile_definitions SLICE_FILE)
+function(asterisk_scf_slice_compile_definitions SLICE_FILE)
   get_filename_component(SLICE ${SLICE_FILE} NAME_WE)
   set(SLICE_COMPILE_DEFINITIONS_${SLICE} ${ARGN} PARENT_SCOPE)
 endfunction()
 
 # Function which remembers Ice libraries needed by a Slice target
-function(hydra_slice_add_ice_libraries TARGET)
+function(asterisk_scf_slice_add_ice_libraries TARGET)
   if(NOT ARGN)
     message(FATAL_ERROR "You must pass at least one library to this function")
   endif()
   set(libs ${${TARGET}_ICE_LIBRARIES})
   foreach(lib ${ARGN})
-    foreach(lang ${HYDRA_PROJECT_LANGUAGES})
+    foreach(lang ${ASTERISK_SCF_PROJECT_LANGUAGES})
       if(lang STREQUAL "Java")
 	find_ICE_Java_library(${lib})
       elseif(lang STREQUAL "CSharp")
@@ -371,11 +371,11 @@ function(hydra_slice_add_ice_libraries TARGET)
 endfunction()
 
 # Function which adds a dependency for a Slice definition
-function(hydra_slice_add_dependencies TARGET)
+function(asterisk_scf_slice_add_dependencies TARGET)
   if(NOT ARGN)
     message(FATAL_ERROR "You must pass at least one dependency to this function")
   endif()
-  foreach(l ${HYDRA_PROJECT_LANGUAGES})
+  foreach(l ${ASTERISK_SCF_PROJECT_LANGUAGES})
     foreach(d ${ARGN})
       message(STATUS "Adding dependency on slice definition ${d} to ${TARGET} for ${l} language")
       add_dependencies(${TARGET}_${l} ${d}_${l})
@@ -387,7 +387,7 @@ endfunction()
 # the file(s) are compiled for all languages in use in the project
 #
 # Syntax:
-# hydra_compile_slice(<target> [SOURCES source1 ... sourceN])
+# asterisk_scf_compile_slice(<target> [SOURCES source1 ... sourceN])
 #
 # Notes:
 # If only a target name is provided, it must include the '.ice'
@@ -402,19 +402,19 @@ endfunction()
 # sets these variables (where SLICE is the target name computed
 # as above and LANG is each language used in the project):
 #
-# HYDRA_SLICE_${SLICE}_${LANG}
+# ASTERISK_SCF_SLICE_${SLICE}_${LANG}
 #  marker indicating this Slice has been built for the language
-# HYDRA_SLICE_${SLICE}_CXX_INCLUDE_DIRS
+# ASTERISK_SCF_SLICE_${SLICE}_CXX_INCLUDE_DIRS
 #  directories where generated header files needed for this target live
 #  (only for C++)
-function(hydra_compile_slice TARGET_IN DIR_IN DESC_IN GROUP_IN)
+function(asterisk_scf_compile_slice TARGET_IN DIR_IN DESC_IN GROUP_IN)
   if(ARGN)
     foreach(arg ${ARGN})
       if(NOT source_mode)
 	if(arg STREQUAL "SOURCES")
 	  set(source_mode true)
 	else()
-	  message(FATAL_ERROR "Unsupported argument '${arg}' passed to hydra_compile_slice")
+	  message(FATAL_ERROR "Unsupported argument '${arg}' passed to asterisk_scf_compile_slice")
 	endif()
       else()
 	list(APPEND inputs "${arg}")
@@ -495,7 +495,7 @@ function(hydra_compile_slice TARGET_IN DIR_IN DESC_IN GROUP_IN)
     set_cache_var(TARGET_${file_variable} ${TARGET})
   endforeach()
 
-  foreach(lang ${HYDRA_PROJECT_LANGUAGES})
+  foreach(lang ${ASTERISK_SCF_PROJECT_LANGUAGES})
     unset(generated_files)
     unset(target_dependencies)
     unset(source_dependencies)
@@ -561,7 +561,7 @@ function(hydra_compile_slice TARGET_IN DIR_IN DESC_IN GROUP_IN)
 	    message(STATUS "Auto-adding dependency on Slice target ${dep_target} to ${TARGET} for ${lang} language")
 	    list(APPEND source_dependencies ${dep})
 	    list(APPEND target_dependencies ${dep_target}_${lang})
-	    list(APPEND target_CXX_includes ${HYDRA_SLICE_${dep_target}_CXX_INCLUDE_DIRS})
+	    list(APPEND target_CXX_includes ${ASTERISK_SCF_SLICE_${dep_target}_CXX_INCLUDE_DIRS})
 	  endif()
 	else()
 	  # Remember sources that are not associated with targets too
@@ -606,7 +606,7 @@ function(hydra_compile_slice TARGET_IN DIR_IN DESC_IN GROUP_IN)
       # Note that slice_files are included as sources here even though they won't be compiled
       # by the actual compiler; this is to get them to show up as sources in the project
       # created for this target
-      foreach(lib ${${TARGET}_ICE_LIBRARIES} ${HYDRA_ICE_LIBRARIES_${lang}})
+      foreach(lib ${${TARGET}_ICE_LIBRARIES} ${ASTERISK_SCF_ICE_LIBRARIES_${lang}})
 	list(APPEND target_libs "${ICE_${lang}_LIB_${lib}}")
       endforeach()
       csharp_add_library(${TARGET}_${lang} ${generated_files} ${slice_files}
@@ -623,7 +623,7 @@ function(hydra_compile_slice TARGET_IN DIR_IN DESC_IN GROUP_IN)
 	 # as a COMPONENT arg to install. 
          cpack_add_component(${TARGET}_${lang} DESCRIPTION ${DESC_IN} GROUP ${GROUP_IN})
       endif()
-      foreach(lib ${${TARGET}_ICE_LIBRARIES} ${HYDRA_ICE_LIBRARIES_${lang}})
+      foreach(lib ${${TARGET}_ICE_LIBRARIES} ${ASTERISK_SCF_ICE_LIBRARIES_${lang}})
 	list(APPEND target_libs "${ICE_${lang}_LIB_${lib}}")
       endforeach()
       if(target_libs)
@@ -641,36 +641,36 @@ function(hydra_compile_slice TARGET_IN DIR_IN DESC_IN GROUP_IN)
       if(UNIX)
 	set_target_properties(${TARGET}_${lang} PROPERTIES COMPILE_FLAGS "-fPIC")
       endif()
-      set_cache_var(HYDRA_SLICE_${TARGET}_CXX_INCLUDE_DIRS ${CMAKE_CURRENT_BINARY_DIR} ${target_CXX_includes})
+      set_cache_var(ASTERISK_SCF_SLICE_${TARGET}_CXX_INCLUDE_DIRS ${CMAKE_CURRENT_BINARY_DIR} ${target_CXX_includes})
     endif()
-    set_cache_var(HYDRA_SLICE_${TARGET}_${lang} Bob)
+    set_cache_var(ASTERISK_SCF_SLICE_${TARGET}_${lang} Bob)
   endforeach()
 endfunction()
 
 # Function which initializes a component for building
-function(hydra_component_init COMPONENT LANG)
+function(asterisk_scf_component_init COMPONENT LANG)
   message(STATUS "Setting up to build component ${COMPONENT}")
-  set(HYDRA_${COMPONENT}_LANG ${LANG} PARENT_SCOPE)
+  set(ASTERISK_SCF_${COMPONENT}_LANG ${LANG} PARENT_SCOPE)
 endfunction()
 
 # Function which adds the compiled Slice targets to a component to be built
-function(hydra_component_add_slice COMPONENT)
+function(asterisk_scf_component_add_slice COMPONENT)
   if(NOT ARGN)
     message(FATAL_ERROR "You must pass at least one Slice target to this function")
   endif()
-  if(NOT HYDRA_${COMPONENT}_LANG)
-    message(FATAL_ERROR "Must call hydra_component_init for component ${COMPONENT} before hydra_component_add_slice")
+  if(NOT ASTERISK_SCF_${COMPONENT}_LANG)
+    message(FATAL_ERROR "Must call asterisk_scf_component_init for component ${COMPONENT} before asterisk_scf_component_add_slice")
   endif()
   set(slice_list ${${COMPONENT}_SLICES})
   foreach(slice ${ARGN})
     get_filename_component(f ${slice} NAME_WE)
-    if(NOT HYDRA_SLICE_${f}_${HYDRA_${COMPONENT}_LANG})
-      message(FATAL_ERROR "Must call hydra_compile_slice for ${f} before hydra_component_add_slice")
+    if(NOT ASTERISK_SCF_SLICE_${f}_${ASTERISK_SCF_${COMPONENT}_LANG})
+      message(FATAL_ERROR "Must call asterisk_scf_compile_slice for ${f} before asterisk_scf_component_add_slice")
     endif()
     message(STATUS "Adding Slice ${f} to component ${COMPONENT}")
-    list(APPEND slice_list ${f}_${HYDRA_${COMPONENT}_LANG})
-    if(HYDRA_${COMPONENT}_LANG STREQUAL "CXX")
-      list(APPEND include_dirs ${HYDRA_SLICE_${slice}_CXX_INCLUDE_DIRS})
+    list(APPEND slice_list ${f}_${ASTERISK_SCF_${COMPONENT}_LANG})
+    if(ASTERISK_SCF_${COMPONENT}_LANG STREQUAL "CXX")
+      list(APPEND include_dirs ${ASTERISK_SCF_SLICE_${slice}_CXX_INCLUDE_DIRS})
     endif()
   endforeach()
   list(REMOVE_DUPLICATES slice_list)
@@ -682,7 +682,7 @@ function(hydra_component_add_slice COMPONENT)
 endfunction()
 
 # Function which adds source or header files to a component to be built
-function(hydra_component_add_file COMPONENT)
+function(asterisk_scf_component_add_file COMPONENT)
   if(NOT ARGN)
     message(FATAL_ERROR "You must pass at least one source file to this function")
   endif()
@@ -690,7 +690,7 @@ function(hydra_component_add_file COMPONENT)
   set(file_list ${${COMPONENT}_SOURCES})
   foreach(file ${ARGN})
     list(APPEND file_list ${CMAKE_CURRENT_SOURCE_DIR}/${file})
-    if(HYDRA_${COMPONENT}_LANG STREQUAL "CXX" AND CMAKE_COMPILER_IS_GNUCXX AND CMAKE_BUILD_TYPE STREQUAL Debug)
+    if(ASTERISK_SCF_${COMPONENT}_LANG STREQUAL "CXX" AND CMAKE_COMPILER_IS_GNUCXX AND CMAKE_BUILD_TYPE STREQUAL Debug)
       set_source_files_properties(${file} COMPILE_FLAGS "-Wall -Werror")
     endif()
   endforeach()
@@ -699,13 +699,13 @@ function(hydra_component_add_file COMPONENT)
 endfunction()
 
 # Function which adds Ice libraries needed by a component
-function(hydra_component_add_ice_libraries COMPONENT)
+function(asterisk_scf_component_add_ice_libraries COMPONENT)
   if(NOT ARGN)
     message(FATAL_ERROR "You must pass at least one library to this function")
   endif()
   set(libs ${${COMPONENT}_ICE_LIBRARIES})
   foreach(lib ${ARGN})
-    set(lang ${HYDRA_${COMPONENT}_LANG})
+    set(lang ${ASTERISK_SCF_${COMPONENT}_LANG})
     if(lang STREQUAL "Java")
       find_ICE_Java_library(${lib})
     elseif(lang STREQUAL "CSharp")
@@ -720,13 +720,13 @@ function(hydra_component_add_ice_libraries COMPONENT)
 endfunction()
 
 # Function which adds Boost libraries needed by a component
-function(hydra_component_add_boost_libraries COMPONENT)
+function(asterisk_scf_component_add_boost_libraries COMPONENT)
   if(NOT ARGN)
     message(FATAL_ERROR "You must pass at least one library to this function")
   endif()
   set(libs ${${COMPONENT}_BOOST_LIBRARIES})
   foreach(lib ${ARGN})
-    set(lang ${HYDRA_${COMPONENT}_LANG})
+    set(lang ${ASTERISK_SCF_${COMPONENT}_LANG})
     if(lang STREQUAL "CXX")
     else()
       message(FATAL_ERROR "Boost libraries cannot be used with components in the ${lang} language")
@@ -741,8 +741,8 @@ function(hydra_component_add_boost_libraries COMPONENT)
 endfunction()
 
 # Function which builds a component as an IceBox service
-function(hydra_component_build_icebox COMPONENT)
-  set(lang ${HYDRA_${COMPONENT}_LANG})
+function(asterisk_scf_component_build_icebox COMPONENT)
+  set(lang ${ASTERISK_SCF_${COMPONENT}_LANG})
   message(STATUS "Building component ${COMPONENT} (${lang}) as IceBox service")
   if(lang STREQUAL "CXX")
     find_ICE_CXX_library(IceBox)
@@ -753,7 +753,7 @@ function(hydra_component_build_icebox COMPONENT)
   else()
     message(FATAL_ERROR "IceBox services are not supported in the ${lang} language")
   endif()
-  list(APPEND icelibs IceBox ${HYDRA_ICE_LIBRARIES_${lang}} ${${COMPONENT}_ICE_LIBRARIES})
+  list(APPEND icelibs IceBox ${ASTERISK_SCF_ICE_LIBRARIES_${lang}} ${${COMPONENT}_ICE_LIBRARIES})
   list(REMOVE_DUPLICATES icelibs)
   foreach(lib ${icelibs})
     list(APPEND target_libs "${ICE_${lang}_LIB_${lib}}")
@@ -766,7 +766,7 @@ function(hydra_component_build_icebox COMPONENT)
     # (it loads .dylib instead of loading .so)
     add_library(${COMPONENT} SHARED ${${COMPONENT}_SOURCES})
     # Link required libraries and Slice libraries
-    list(APPEND boostlibs ${HYDRA_BOOST_LIBRARIES} ${${COMPONENT}_BOOST_LIBRARIES})
+    list(APPEND boostlibs ${ASTERISK_SCF_BOOST_LIBRARIES} ${${COMPONENT}_BOOST_LIBRARIES})
     if(boostlibs)
       list(REMOVE_DUPLICATES boostlibs)
       foreach(lib ${boostlibs})
@@ -781,10 +781,10 @@ function(hydra_component_build_icebox COMPONENT)
 endfunction()
 
 # Function which builds a component standalone
-function(hydra_component_build_standalone COMPONENT)
-  set(lang ${HYDRA_${COMPONENT}_LANG})
+function(asterisk_scf_component_build_standalone COMPONENT)
+  set(lang ${ASTERISK_SCF_${COMPONENT}_LANG})
   message(STATUS "Building component ${COMPONENT} (${lang}) as standalone executable")
-  list(APPEND icelibs ${HYDRA_ICE_LIBRARIES_${lang}} ${${COMPONENT}_ICE_LIBRARIES})
+  list(APPEND icelibs ${ASTERISK_SCF_ICE_LIBRARIES_${lang}} ${${COMPONENT}_ICE_LIBRARIES})
   list(REMOVE_DUPLICATES icelibs)
   foreach(lib ${icelibs})
     list(APPEND target_libs "${ICE_${lang}_LIB_${lib}}")
@@ -794,7 +794,7 @@ function(hydra_component_build_standalone COMPONENT)
     # Now we actually create the component
     add_executable(${COMPONENT} ${${COMPONENT}_SOURCES})
     # Link required libraries and Slice libraries
-    list(APPEND boostlibs ${HYDRA_BOOST_LIBRARIES} ${${COMPONENT}_BOOST_LIBRARIES})
+    list(APPEND boostlibs ${ASTERISK_SCF_BOOST_LIBRARIES} ${${COMPONENT}_BOOST_LIBRARIES})
     if(boostlibs)
       list(REMOVE_DUPLICATES boostlibs)
       foreach(lib ${boostlibs})
@@ -808,10 +808,10 @@ function(hydra_component_build_standalone COMPONENT)
   endif()
 endfunction()
 
-function(hydra_component_build_library COMPONENT)
-  set(lang ${HYDRA_${COMPONENT}_LANG})
+function(asterisk_scf_component_build_library COMPONENT)
+  set(lang ${ASTERISK_SCF_${COMPONENT}_LANG})
   message(STATUS "Building component ${COMPONENT} (${lang}) as standalone executable")
-  list(APPEND icelibs ${HYDRA_ICE_LIBRARIES_${lang}} ${${COMPONENT}_ICE_LIBRARIES})
+  list(APPEND icelibs ${ASTERISK_SCF_ICE_LIBRARIES_${lang}} ${${COMPONENT}_ICE_LIBRARIES})
 
   list(LENGTH icelibs numicelibs)
   if(numicelibs GREATER 0)
@@ -826,7 +826,7 @@ function(hydra_component_build_library COMPONENT)
     # Now we actually create the component
     add_library(${COMPONENT} ${${COMPONENT}_SOURCES})
     # Link required libraries and Slice libraries
-    list(APPEND boostlibs ${HYDRA_BOOST_LIBRARIES} ${${COMPONENT}_BOOST_LIBRARIES})
+    list(APPEND boostlibs ${ASTERISK_SCF_BOOST_LIBRARIES} ${${COMPONENT}_BOOST_LIBRARIES})
     if(boostlibs)
       list(REMOVE_DUPLICATES boostlibs)
       foreach(lib ${boostlibs})
@@ -841,23 +841,23 @@ function(hydra_component_build_library COMPONENT)
 endfunction()
 
 # Function which adds information for installing a component
-function(hydra_component_install COMPONENTNAME TYPE DIR DESC GROUP)
+function(asterisk_scf_component_install COMPONENTNAME TYPE DIR DESC GROUP)
   install(TARGETS ${COMPONENTNAME} ${TYPE} DESTINATION ${DIR} COMPONENT ${COMPONENTNAME} ${ARGN})
 
    if(ASTERISKSCF_CPACK)
-      hydra_component_package(${COMPONENTNAME} ${DESC} ${GROUP})
+      asterisk_scf_component_package(${COMPONENTNAME} ${DESC} ${GROUP})
    endif()
 endfunction()
 
 # Adds a component to the packager. COMPONENTNAME must have been previously defined
 # via the install command. 
-function(hydra_component_package COMPONENTNAME DESC GROUPNAME)
+function(asterisk_scf_component_package COMPONENTNAME DESC GROUPNAME)
       cpack_add_component(${COMPONENTNAME} DESCRIPTION ${DESC} GROUP ${GROUP})
 endfunction()
 
 # Adds a boost test executable to CTest.  These executable will be run
 # with 'make test' @param EXE - boost test executable.  Probably built
-# using hydra_component_build_standalone.
+# using asterisk_scf_component_build_standalone.
 function(boost_add_test EXE)
    add_test(NAME ${EXE} COMMAND ${EXE}
       --report_sink=${CMAKE_BINARY_DIR}/${EXE}-result.xml
@@ -219,22 +219,22 @@ function(find_Boost_library LIBRARY)
   project(${NAME} ${ARGN})
   # On Windows, IceBox C++ services must be compiled with some symbols exported;
-  # the source code should use HYDRA_ICEBOX_EXPORT to accomplish this, and this
+  # the source code should use ASTERISK_SCF_ICEBOX_EXPORT to accomplish this, and this
   # block will ensure it contains the correct value.
   if(WIN32)
-- 
asterisk-scf/release/cmake.git



More information about the asterisk-scf-commits mailing list